pub enum PagerSnapQuery {
Between(SnapPoint, SnapPoint),
Beyond(SnapPoint),
}Expand description
Any number can be either between two snap points, or beyond one of the extents.
Variants
Between(SnapPoint, SnapPoint)
The queried value lies between these two snap points.
Beyond(SnapPoint)
The queried value lies beyond this snap point.